@@ -175,6 +175,7 @@ void PendingCallPrivate::processFileTransferListReply(const QDBusPendingReply<QV
     processError(reply.error());
     if (!reply.isError()) {
         QList<ObexFileTransferEntry> items;
+        items.reserve(reply.value().size());
         Q_FOREACH (const QVariantMap &map, reply.value()) {
             items.append(ObexFileTransferEntry(map));
         }
@@ -222,7 +223,7 @@ void PendingCallPrivate::emitDelayedFinished()
 
 void PendingCallPrivate::emitInternalError(const QString &errorText)
 {
-    qCWarning(BLUEZQT) << "PendingCall Error:" << errorText;
+    qCWarning(BLUEZQT) << "PendingCall Internal error:" << errorText;
     m_error = PendingCall::InternalError;
     m_errorText = errorText;
     emitFinished();
